pub trait Strategy {
// Required methods
fn status(&self) -> Option<Status>;
fn update(&self, status: Status) -> Option<Status>;
}Expand description
Defining the Debouncing Algorithm
The strategy needs to do everything to debounce the input, but it should not store the most recent state.